@@ -1,5 +1,10 @@
 aictab.mult <-
   function(cand.set, modnames, sort=TRUE, c.hat=1, second.ord=TRUE, nobs=NULL){  #specify whether table should be sorted or not by delta AICc
+
+    ##add check to see whether response variable is the same for all models
+    check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
+    if(length(unique(check.resp)) > 1) stop("You must use the same response variable for all models\n")
+    
     Results <- NULL
     Results<-data.frame(Modnames=modnames)                    #assign model names to first column
     Results$K<-unlist(lapply(X=cand.set, FUN=AICc.mult, return.K=TRUE, c.hat=c.hat,
