@@ -127,7 +127,8 @@ for (i in 1:nmods) {
   new.cand.set<-cand.set[which(include==1)] #select models including a given parameter
   new.mod.name<-modnames[which(include==1)]    #update model names
 
-  new_table<-aictab.lme(cand.set=new.cand.set, modnames=new.mod.name, sort=FALSE, second.ord=second.ord, nobs=nobs)  #recompute AIC table and associated measures
+  new_table<-aictab.lme(cand.set=new.cand.set, modnames=new.mod.name, sort=FALSE,
+                        second.ord=second.ord, nobs=nobs)  #recompute AIC table and associated measures
   new_table$Beta_est<-unlist(lapply(new.cand.set, FUN=function(i) fixef(i)[paste(parm)])) #extract beta estimate for parm
   new_table$SE<-unlist(lapply(new.cand.set, FUN=function(i) sqrt(diag(vcov(i)))[paste(parm)]))
   
@@ -165,7 +166,9 @@ for (i in 1:nmods) {
 zcrit <- qnorm(p=(1-conf.level)/2, lower.tail=FALSE)
 Lower_CL<-Modavg_beta-zcrit*Uncond_SE
 Upper_CL<-Modavg_beta+zcrit*Uncond_SE
-out.modavg <- list("Parameter"=paste(parm), "Mod.avg.table" = new_table, "Mod.avg.beta" = Modavg_beta, "Uncond.SE" = Uncond_SE, "Conf.level" = conf.level, "Lower.CL" = Lower_CL, "Upper.CL" = Upper_CL)
+out.modavg <- list("Parameter"=paste(parm), "Mod.avg.table" = new_table, "Mod.avg.beta" = Modavg_beta,
+                   "Uncond.SE" = Uncond_SE, "Conf.level" = conf.level, "Lower.CL" = Lower_CL,
+                   "Upper.CL" = Upper_CL)
   
   class(out.modavg) <- c("modavg", "list")
   return(out.modavg)
